==> jc-1.4.0.tar.gz: polyglot/types/PrimitiveType.h <==
// public abstract interface polyglot.types.PrimitiveType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c9050be6d71cb6f4 polyglot_types_PrimitiveType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_PrimitiveType_H_
#define _JC_polyglot_types_PrimitiveType_H_

// Typedefs
typedef struct _jc_polyglot_types_PrimitiveType$fields_struct	_jc_polyglot_types_PrimitiveType$fields_struct;
typedef const struct _jc_polyglot_types_PrimitiveType$vtype	_jc_polyglot_types_PrimitiveType$vtype;

// Class fields structure
struct _jc_polyglot_types_PrimitiveType$fields_struct {
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*BOOLEAN;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*BYTE;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*CHAR;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*DOUBLE;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*FLOAT;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*INT;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*LONG;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*SHORT;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*VOID;
};
extern _jc_polyglot_types_PrimitiveType$fields_struct _jc_polyglot_types_PrimitiveType$class_fields;

// Static methods
extern void _jc_polyglot_types_PrimitiveType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_polyglot_types_PrimitiveType$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_types_PrimitiveType$vtype _jc_polyglot_types_PrimitiveType$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_PrimitiveType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_PrimitiveType$class_object;

#endif	/* _JC_polyglot_types_PrimitiveType_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/PrimitiveType.h <==
// public abstract interface polyglot.types.PrimitiveType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c9050be6d71cb6f4 polyglot_types_PrimitiveType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_PrimitiveType_H_
#define _JC_polyglot_types_PrimitiveType_H_

// Typedefs
typedef struct _jc_polyglot_types_PrimitiveType$fields_struct	_jc_polyglot_types_PrimitiveType$fields_struct;
typedef const struct _jc_polyglot_types_PrimitiveType$vtype	_jc_polyglot_types_PrimitiveType$vtype;

// Class fields structure
struct _jc_polyglot_types_PrimitiveType$fields_struct {
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*BOOLEAN;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*BYTE;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*CHAR;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*DOUBLE;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*FLOAT;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*INT;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*LONG;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*SHORT;
	struct _jc_polyglot_types_PrimitiveType__24Kind$object	*VOID;
};
extern _jc_polyglot_types_PrimitiveType$fields_struct _jc_polyglot_types_PrimitiveType$class_fields;

// Static methods
extern void _jc_polyglot_types_PrimitiveType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_polyglot_types_PrimitiveType$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_types_PrimitiveType$vtype _jc_polyglot_types_PrimitiveType$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_PrimitiveType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_PrimitiveType$class_object;

#endif	/* _JC_polyglot_types_PrimitiveType_H_ */
